/*
 * RealTimeTaskImpl.cc
 *
 * Copyright (c) 2003, 2004 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file RealTimeTaskImpl.cc
 *
 * Implementation of the RealTimeTaskImpl class.
 */

#include "config.h"

#include <string.h>

#include <iostream>
#include <fstream>
#include <iomanip>

#include <assert_pp.h>
#include <time_util.h>
#include <instrumentation.h>

#include "RealTimeTaskImpl.hh"

using namespace std;

#if !defined(__XSTRING)
/**
 * Convert a macro argument to a string.
 *
 * @param x The macro to expand to a string.
 */
#define __XSTRING(x) __STRING(x)
#endif

RealTimeTaskImpl::RealTimeTaskImpl(const Broker::TaskParameters &tp)
    throw (CORBA::SystemException,
	   Broker::DuplicateTaskParameter,
	   Broker::InvalidTaskParameter,
	   Broker::MissingTaskParameter)
{
    unsigned int lpc;

    /* Process the arguments */
    for( lpc = 0; lpc < tp.length(); lpc++ )
    {
	if( strcasecmp(tp[lpc].name.in(), "name") == 0 )
	{
	    const char *name;

	    if( this->rtti_Name != NULL )
	    {
		throw Broker::DuplicateTaskParameter("name");
	    }
	    else if( tp[lpc].value >>= name )
	    {
		this->rtti_Name = name;
	    }
	    else
	    {
		throw Broker::InvalidTaskParameter("'name' not a string",
						   tp[lpc]);
	    }
	}
    }
    
    /* Make sure we have everything we need. */
    if( this->rtti_Name == NULL )
    {
	throw Broker::MissingTaskParameter("name");
    }
}

RealTimeTaskImpl::~RealTimeTaskImpl()
{
}

char *RealTimeTaskImpl::Name(void)
    throw (CORBA::SystemException)
{
    CORBA::String_var retval;

    retval = this->rtti_Name;
    return( retval._retn() );
}

void RealTimeTaskImpl::SetManager(Broker::Manager_ptr manager)
    throw (CORBA::SystemException)
{
    this->rtti_Manager = Broker::Manager::_duplicate(manager);
}

Broker::CPUReserve
RealTimeTaskImpl::PassCPU(Broker::RealTimeTask_ptr rtt,
			  const Broker::CPUReserve &status,
			  const Broker::CPUReserve &advice,
			  const Broker::KeyedReportParameters &krp)
    throw (CORBA::SystemException)
{
    if( CORBA::is_nil(this->rtti_Manager.in()) )
    {
	throw CORBA::BAD_INV_ORDER();
    }
    if( CORBA::is_nil(rtt) )
    {
	throw CORBA::BAD_PARAM();
    }
    
    return( this->rtti_Manager->ChangeTaskCPU(rtt, advice) );
}
