/*
 * real_time_schedule.cc
 *
 * Copyright (c) 2003 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file real_time_schedule.cc
 *
 * Test cases for the RealTimeSchedule class.
 */

#include "config.h"

#if !defined(DEBUG)
#define DEBUG 1
#endif

#include <iostream>

#include <assert.h>

#include <RealTimeSchedule.hh>

int main(int argc, char *argv[])
{
    int retval = 0;

    /* Test a simple case where period == deadline. */
    {
	RealTimeSchedule rts(0, 1000, 1000);
	
	assert(rts.intersect(0, 1000) == 1000);
	assert(rts.intersect(250, 1000) == 750);
	assert(rts.intersect(500, 1000) == 500);

	assert(rts.intersect(0, 5000) == 5000);
	assert(rts.intersect(250, 5000) == 4750);
	assert(rts.intersect(500, 5000) == 4500);

	assert(rts.intersect(0, 750) == 750);
	assert(rts.intersect(0, 500) == 500);

	assert(rts.intersect(250, 750) == 500);
	assert(rts.intersect(500, 750) == 250);
	assert(rts.intersect(500, 500) == 0);
    }

    /* Test for deadline < period. */
    {
	RealTimeSchedule rts(0, 1000, 500);
	
	assert(rts.intersect(0, 1000) == 500);
	assert(rts.intersect(250, 1000) == 250);
	assert(rts.intersect(500, 1000) == 0);

	assert(rts.intersect(0, 5000) == 2500);
	assert(rts.intersect(250, 5000) == 2250);
	assert(rts.intersect(500, 5000) == 2000);
    }

    /* Test for start time. */
    {
	RealTimeSchedule rts(500, 500, 500);
	
	assert(rts.intersect(0, 1000) == 500);
	assert(rts.intersect(500, 1000) == 500);
	assert(rts.intersect(250, 750) == 250);
	assert(rts.intersect(500, 750) == 250);
    }
    
    {
	RealTimeSchedule rts(750, 1000, 500);
	
	assert(rts.intersect(1000, 2000) == 500);
    }
    
    return( retval );
}
