/*
 * StrictPolicyCallbackImpl.hh
 *
 * Copyright (c) 2003, 2004 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file StrictPolicyCallbackImpl.hh
 *
 * Header file for the StrictPolicyCallbackImpl class.
 */

#ifndef _strict_policy_callback_impl_hh
#define _strict_policy_callback_impl_hh

#include "BasicTaskCallbackS.h"
#include "StrictPolicyC.h"

/**
 * A straight forward implementation of a
 * Qosket::StrictPolicy::StrictPolicyCallback.
 *
 * @sa Qosket::StrictPolicy::StrictPolicyCallback
 */
class StrictPolicyCallbackImpl :
    public virtual POA_Qosket::StrictPolicy::StrictPolicyCallback
{

public:

    /**
     * Construct a StrictPolicyCallbackImpl that manages the given policy.
     *
     * @param sp The BrokerPolicies::StrictPolicy object to control.
     */
    StrictPolicyCallbackImpl(BrokerPolicies::StrictPolicy_ptr sp);

    /**
     * Deconstruct a StrictPolicyCallbackImpl object.
     */
    virtual ~StrictPolicyCallbackImpl(void);

    /**
     * Send a message to the call back.  This is also used by the other methods
     * to do logging.
     *
     * @param msg The message to log.
     */
    virtual void sendMessage(const char *msg)
	throw (CORBA::SystemException);

    /** @copydoc Qosket::StrictPolicy::StrictPolicyCallback::SetPriorityOf */
    virtual void SetPriorityOf(const char *task_name, CORBA::Short priority)
	throw (CORBA::SystemException);
    
    /** @copydoc Qosket::StrictPolicy::StrictPolicyCallback::GetPriorityOf */
    virtual CORBA::Short GetPriorityOf(const char *task_name)
	throw (CORBA::SystemException);

protected:

    /**
     * Reference to the current ORB for this process.
     */
    CORBA::ORB_ptr spci_ORB;

    /**
     * Reference to the policy object to control.
     */
    BrokerPolicies::StrictPolicy_var spci_Policy;
    
};

#endif
