/*
 * BasicTaskQosketImpl.java
 *
 * Copyright (c) 2003, 2004 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file BasicTaskQosketImpl.java
 *
 * Default implementation of a Qosket::Basic::BasicTaskQosket.
 */

package Qosket.Basic;

import com.bbn.quo.corba.QuoKernel;
import com.bbn.quo.corba.ValueSC;
import com.bbn.quo.corba.Callback;
import com.bbn.quo.corba.ValueSCHelper;
import com.bbn.quo.corba.impl.Connector;

import rk.ResourceSet;

/**
 * A subclass of the Qosket::Basic::BasicTaskQosketSkel class generated from
 * the BasicTaskContract.  The implementation is pretty straightforward, it
 * gets its system conditions from the quo::QuoKernel and creates the callback
 * itself.
 *
 * @sa BasicTaskQosketImpl
 * @sa Qosket::Basic::BasicTaskCallback
 * @sa BasicTaskCallbackImpl
 * @sa StubBasicTaskCallback
 * @sa BasicTaskContract.cdl
 */
public class BasicTaskQosketImpl
    extends BasicTaskQosketSkel
{
    /**
     * Initialize the internal QuO system conditions.
     *
     * @param kernel The QuO kernel to get the system conditions from.
     */
    public void initSysconds(QuoKernel kernel)
    {
	org.omg.CORBA.Object raw =
	    Connector.instantiateSysCond(kernel,
					 "DeadlinesMissed",
					 "quo::ValueSC",
					 "quo_sc::ValueSCImpl");
	this.myDeadlinesMissed = ValueSCHelper.narrow(raw);

	raw = Connector.instantiateSysCond(kernel,
					   "LastStatus",
					   "quo::ValueSC",
					   "quo_sc::ValueSCImpl");
	this.myLastStatus = ValueSCHelper.narrow(raw);
    }

    /**
     * Initialize the internal call back object.
     */
    public void initCallbacks()
    {
	BasicTaskCallbackImpl btci;

	btci = new BasicTaskCallbackImpl("BasicTaskCallback");
	try
	{
	    (com.bbn.quo.corba.impl.Connector.quoPOA()).
		activate_object(btci);
	}
	catch(Exception e)
	{
	    e.printStackTrace();
	}
	this.myCallback = btci._this();
    }

    /** @copydoc Qosket::Basic::BasicTaskQosket::DeadlinesMissed */
    public ValueSC DeadlinesMissed()
    {
	return this.myDeadlinesMissed;
    }

    /** @copydoc Qosket::Basic::BasicTaskQosket::LastStatus */
    public ValueSC LastStatus()
    {
	return this.myLastStatus;
    }

    /** @copydoc Qosket::Basic::BasicTaskQosket::Callback */
    public Callback Callback()
    {
	return this.myCallback;
    }

    /** @copydoc Qosket::Basic::BasicTaskQosket::RUsage */
    public synchronized long RUsage()
    {
	long retval = rk.ResourceSet.getUsage();
	
	return retval;
    }

    /**
     * @see java.lang.Object#toString()
     */
    public String toString()
    {
	return "BasicTaskQosketImpl["
	    + super.toString()
	    + "]";
    }
}
